@@ -131,13 +131,13 @@ debit_table <- function(x, sd, n,
   sd_upper_test    <- dustify(sd_upper)
 
   if (sd_incl_lower && sd_incl_upper) {
-    consistency <- any(sd_lower_test <= sd_rec_both_test) && any(sd_rec_both_test <= sd_upper_test)
+    consistency <- any(outer(sd_lower_test, sd_rec_both_test, "<=")) && any(outer(sd_rec_both_test, sd_upper_test, "<="))
   } else if (sd_incl_lower && !sd_incl_upper) {
-    consistency <- any(sd_lower_test <= sd_rec_both_test) && any(sd_rec_both_test  < sd_upper_test)
+        consistency <- any(outer(sd_lower_test, sd_rec_both_test, "<=")) && any(outer(sd_rec_both_test, sd_upper_test, "<"))
   } else if (!sd_incl_lower && sd_incl_upper) {
-    consistency <- any(sd_lower_test < sd_rec_both_test)  && any(sd_rec_both_test <= sd_upper_test)
+        consistency <- any(outer(sd_lower_test, sd_rec_both_test, "<")) && any(outer(sd_rec_both_test, sd_upper_test, "<="))
   } else {
-    consistency <- any(sd_lower_test < sd_rec_both_test)  && any(sd_rec_both_test  < sd_upper_test)
+        consistency <- any(outer(sd_lower_test, sd_rec_both_test, "<")) && any(outer(sd_rec_both_test, sd_upper_test, "<"))
   }
 
   # `n` is always a whole number, so it's good to convert it to integer:
