@@ -8,7 +8,7 @@ utils::globalVariables(c(
   "rounding", "case", "n_sum", "consistency", "ratio", "scr_index_case",
   "starts_with", "value_duplicated", "variable", "sd_lower",
   "sd_incl_lower", "sd_upper", "sd_incl_upper", "x_lower", "x_upper",
-  "dupe_count", "fun_name",
+  "dupe_count", "fun_name", "!!<-",
   # Added after rewriting the function factories using `rlang::new_function()`:
   "!!", "!!!", "constant", "constant_index", "include_consistent",
   "n_min", "n_max",
@@ -503,7 +503,7 @@ check_tibble <- function(x) {
 #'
 #' @noRd
 check_rounding_singular <- function(rounding, bad, good1, good2) {
-  if (any(bad == rounding)) {
+  if (any(bad %in% rounding)) {
     cli::cli_abort(c(
       "!" = "If `rounding` has length > 1, only single rounding procedures \\
       are supported, such as \"{good1}\" and \"{good2}\".",
@@ -1523,30 +1523,60 @@ check_dispersion_linear <- function(data) {
 #'
 #' @param name_key_result String (length 1). The `.name_key_result` argument of
 #'   the function factory, passed to the present function.
+#' @param name_data Expression. It must contain the name of the data frame
+#'   operated on. To construct it, use `rlang::expr()`.
 #'
 #' @return Expression.
 #'
 #' @noRd
-write_code_col_key_result <- function(name_key_result = "consistency") {
+
+# ❯ checking R code for possible problems ... NOTE
+# write_code_col_key_result: no visible binding for global variable ‘out’
+# write_code_col_key_result: no visible global function definition for
+# ‘!!<-’
+# Undefined global functions or variables:
+#   !!<- out
+
+write_code_col_key_result <- function(
+    name_key_result = "consistency",
+    name_data = rlang::expr(out),
+    out = NULL
+) {
   # Enable renaming the `"consistency"` column for binary procedures that are
   # not consistency tests:
   code_rename <- if (name_key_result == "consistency") {
     NULL
   } else {
     rlang::expr({
-      out <- dplyr::rename(out, `!!`(name_key_result) := consistency)
+      `!!`(name_data) <- dplyr::rename(
+        `!!`(name_data),
+        `!!`(name_key_result) := consistency
+      )
     })
   }
+
+  # Prepare defused expressions that are more simple to splice into the code
+  # further below:
+  data_dollar_result <- paste0(name_data, "$", name_key_result)
+  condition_not_list <- paste0("!is.list(", data_dollar_result, ")")
+
+  # Convert the strings to expressions:
+  condition_not_list <- rlang::parse_expr(condition_not_list)
+  data_dollar_result <- rlang::parse_expr(data_dollar_result)
+
   # Generate code to process the (possibly renamed) key result column:
   rlang::expr({
     `!!!`(code_rename)
-    if (!is.list(out$`!!`(name_key_result))) {
-      return(out)
+
+    # Use the pre-computed condition expression
+    if (`!!`(condition_not_list)) {
+      return(`!!`(name_data))
     }
+
     `$<-`(
-      out, `!!`(name_key_result),
-      unlist(out$`!!`(name_key_result), use.names = FALSE)
+      `!!`(name_data),
+      `!!`(name_key_result),
+      unlist(`!!`(data_dollar_result), use.names = FALSE)
     )
   })
 }
-
