@@ -1,6 +1,4 @@
 
-
-
 # `audit()` ---------------------------------------------------------------
 
 
@@ -9,7 +7,7 @@ data_grim  <- grim_map(pigs1)
 audit_grim <- audit(data_grim)
 
 test_that("`audit()` summarizes GRIM tests accurately", {
-  expect_true(is.data.frame(audit_grim))
+  expect_s3_class(audit_grim, "data.frame")
   expect_equal(as.numeric(audit_grim$all_cases - audit_grim$incons_cases),
                length(data_grim$consistency[data_grim$consistency]))
 })
@@ -40,6 +38,38 @@ audit_seq_grim    <- data_grim_seq    %>% audit_seq() %>% unclass_scr()
 audit_seq_grimmer <- data_grimmer_seq %>% audit_seq()
 audit_seq_debit   <- data_debit_seq   %>% audit_seq()
 
+data_seq_grim_different_dispersion1 <- tibble::tibble(
+  x = "4.74",
+  n = 25L,
+  consistency = FALSE,
+  hits_total = 1L,
+  hits_x = 0L,
+  hits_n = 1L,
+  diff_x = NA_integer_,
+  diff_x_up = NA_integer_,
+  diff_x_down = NA_integer_,
+  diff_n = 9L,
+  diff_n_up = 9L,
+  diff_n_down = NA_integer_,
+) %>%
+  structure(class = c("scr_audit_seq", "tbl_df", "tbl", "data.frame"))
+
+data_seq_grim_different_dispersion2 <- tibble::tibble(
+  x = "5.23",
+  n = 29L,
+  consistency = FALSE,
+  hits_total = 3L,
+  hits_x = 1L,
+  hits_n = 2L,
+  diff_x = 5L,
+  diff_x_up = 5L,
+  diff_x_down = NA_integer_,
+  diff_n = 3L,
+  diff_n_up = NA_integer_,
+  diff_n_down = -3L,
+) %>%
+  structure(class = c("scr_audit_seq", "tbl_df", "tbl", "data.frame"))
+
 data_incons <- pigs1 %>%
   grim_map() %>%
   dplyr::filter(!consistency) %>%
@@ -62,7 +92,6 @@ hits_total_is_correct <- function(audit_seq_output) {
     dplyr::select(starts_with("hits"), -hits_total) %>%
     dplyr::mutate(hits_total_expected = sum(dplyr::c_across(everything()))) %>%
     dplyr::pull(hits_total_expected)
-
   all(expected == audit_seq_output$hits_total)
 }
 
@@ -74,3 +103,17 @@ test_that("the `hits_total` column correctly sums up
   audit_seq_debit   %>% hits_total_is_correct() %>% expect_true()
 })
 
+
+test_that("changing `dispersion` in the sequence mapper is
+          correctly captured by `audit_seq()`", {
+  pigs1[1:2, ] %>%
+    grim_map_seq(dispersion = c(7, 8, 9)) %>%
+    audit_seq() %>%
+    expect_equal(data_seq_grim_different_dispersion1)
+
+  tibble::tibble(x = "5.23", n = 29) %>%
+    grim_map_seq(dispersion = c(3, 5, 7)) %>%
+    audit_seq() %>%
+    expect_equal(data_seq_grim_different_dispersion2)
+})
+
